@@ -6,9 +6,8 @@
 
 #pragma once
 
-#include <glib-object.h>
-
 #include "fwupd-enums.h"
+#include "fwupd-report.h"
 
 G_BEGIN_DECLS
 
@@ -62,6 +61,12 @@ void
 fwupd_release_add_checksum(FwupdRelease *self, const gchar *checksum);
 gboolean
 fwupd_release_has_checksum(FwupdRelease *self, const gchar *checksum);
+GPtrArray *
+fwupd_release_get_tags(FwupdRelease *self);
+void
+fwupd_release_add_tag(FwupdRelease *self, const gchar *tag);
+gboolean
+fwupd_release_has_tag(FwupdRelease *self, const gchar *tag);
 
 GHashTable *
 fwupd_release_get_metadata(FwupdRelease *self);
@@ -179,6 +184,18 @@ const gchar *
 fwupd_release_get_update_image(FwupdRelease *self);
 void
 fwupd_release_set_update_image(FwupdRelease *self, const gchar *update_image);
+GPtrArray *
+fwupd_release_get_reports(FwupdRelease *self);
+void
+fwupd_release_add_report(FwupdRelease *self, FwupdReport *report);
+
+gboolean
+fwupd_release_match_flags(FwupdRelease *self, FwupdReleaseFlags include, FwupdReleaseFlags exclude);
+GPtrArray *
+fwupd_release_array_filter_flags(GPtrArray *rels,
+				 FwupdReleaseFlags include,
+				 FwupdReleaseFlags exclude,
+				 GError **error);
 
 FwupdRelease *
 fwupd_release_from_variant(GVariant *value);
